==> linphone-0.10.1-hh1.tar.gz: linphone-0.10.1-hh1/console/sipomatic.h <==
/***************************************************************************
                          linphone  - sipomatic.c
This is a test program for linphone. It acts as a sip server and answers to linphone's
call.
                             -------------------
    begin                : ven mar  30
    copyright            : (C) 2001 by Simon MORLAT
    email                : simon.morlat@free.fr
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/


#include "../osipua/src/osipua.h"
#include "../osipua/src/sdphandler.h"
#undef PACKAGE
#undef VERSION
#include "../oRTP/src/ortp.h"
#include "../oRTP/src/telephonyevents.h"
#include "../mediastreamer/mediastream.h"
#undef PACKAGE
#undef VERSION
#include "../config.h"

#define ANNOUCE_FILE	"hello.wav"

struct _Sipomatic
{
	GMutex *lock;
	GList *audio_codecs;
	OsipUA *ua;
	GList *calls;
	gdouble acceptance_time;
	gdouble max_call_time;
	gchar *file_path;
};

typedef struct _Sipomatic Sipomatic;
	
void sipomatic_init(Sipomatic *obj, gchar *url);
void sipomatic_uninit(Sipomatic *obj);
void sipomatic_iterate(Sipomatic *obj);
#define sipomatic_lock(obj) g_mutex_lock((obj)->lock);
#define sipomatic_unlock(obj) g_mutex_unlock((obj)->lock);

void sipomatic_set_annouce_file(Sipomatic *obj, char *file);

struct _Call
{
	Sipomatic *root;
	GTimer *timer;
	OsipDialog *dialog;
	transaction_t *current_trn;
	AudioStream *audio_stream;
	gint state;
	struct _CallParams *params;
	gint eof;
};

#define CALL_STATE_INIT 0
#define CALL_STATE_RUNNING 1
#define CALL_STATE_FINISHED 2

typedef struct _Call Call;

struct _CallParams
{
	RtpProfile *profile;
	gint ncodecs;
	gint line;
	gint localport;
	gint remoteport;
	gint pt;
	gchar *remaddr;
};
typedef struct _CallParams CallParams;
	
Call * call_new(OsipDialog *dialog);
void call_accept(Call *call);
void call_release(Call *call);
void call_destroy(Call *call);

CallParams *call_params_new();
void call_params_destroy(CallParams *obj);




gboolean sipomatic_check_call(Sipomatic *obj,Call *call);

==> linphone-0.12.2.hh1.tar.gz: linphone-0.12.2.hh1/console/sipomatic.h <==
/***************************************************************************
                          linphone  - sipomatic.c
This is a test program for linphone. It acts as a sip server and answers to linphone's
call.
                             -------------------
    begin                : ven mar  30
    copyright            : (C) 2001 by Simon MORLAT
    email                : simon.morlat@free.fr
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/


#include "../osipua/src/osipua.h"
#include "../osipua/src/sdphandler.h"

#undef PACKAGE
#undef VERSION
#include "../mediastreamer/mediastream.h"

#include "../oRTP/src/telephonyevents.h"


#define ANNOUCE_FILE8000HZ	"hello8000.wav"
#define ANNOUCE_FILE16000HZ	"hello16000.wav"

struct _Sipomatic
{
	GMutex *lock;
	GList *audio_codecs;
	OsipUA *ua;
	GList *calls;
	gdouble acceptance_time;
	gdouble max_call_time;
	gchar *file_path8000hz;
	gchar *file_path16000hz;
};

typedef struct _Sipomatic Sipomatic;
	
void sipomatic_init(Sipomatic *obj, gchar *url);
void sipomatic_uninit(Sipomatic *obj);
void sipomatic_iterate(Sipomatic *obj);
#define sipomatic_lock(obj) g_mutex_lock((obj)->lock);
#define sipomatic_unlock(obj) g_mutex_unlock((obj)->lock);

void sipomatic_set_annouce_file(Sipomatic *obj, char *file);

struct _Call
{
	Sipomatic *root;
	GTimer *timer;
	OsipDialog *dialog;
	transaction_t *current_trn;
	AudioStream *audio_stream;
	gint state;
	struct _CallParams *params;
	gint eof;
};

#define CALL_STATE_INIT 0
#define CALL_STATE_RUNNING 1
#define CALL_STATE_FINISHED 2

typedef struct _Call Call;

struct _CallParams
{
	RtpProfile *profile;
	gint ncodecs;
	gint line;
	gint localport;
	gint remoteport;
	gint pt;
	gchar *remaddr;
};
typedef struct _CallParams CallParams;
	
Call * call_new(OsipDialog *dialog);
void call_accept(Call *call);
void call_release(Call *call);
void call_destroy(Call *call);

CallParams *call_params_new();
void call_params_destroy(CallParams *obj);




gboolean sipomatic_check_call(Sipomatic *obj,Call *call);
